<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// AJAX

add_action( 'wp_ajax_nnr_pp_add_view', 						array('NNRobots_Popular_Posts_Core', 'addView'));
add_action( 'wp_ajax_nopriv_nnr_pp_add_view',				array('NNRobots_Popular_Posts_Core', 'addView'));
add_action( 'wp_ajax_nnr_pp_shortcode_increment', 			array('NNRobots_Popular_Posts_Core', 'shortcodeIncrement'));
add_action( 'wp_ajax_nopriv_nnr_pp_shortcode_increment',	array('NNRobots_Popular_Posts_Core', 'shortcodeIncrement'));

add_action( 'the_content', 									array('NNRobots_Popular_Posts_Core', 'addPostID'));
add_action( 'wp_enqueue_scripts', 							array('NNRobots_Popular_Posts_Core', 'loadAJAXScript'));

// Hooks for tracking comments

add_action( 'comment_post', 								array('NNRobots_Popular_Posts_Core', 'add_comment'), 10, 2);
add_action( 'delete_comment', 								array('NNRobots_Popular_Posts_Core', 'delete_comment'));
add_action( 'trash_comment', 								array('NNRobots_Popular_Posts_Core', 'delete_comment'));
add_action( 'comment_unapproved_to_approved', 				array('NNRobots_Popular_Posts_Core', 'add_approved_comment'));
add_action( 'comment_approved_to_unapproved', 				array('NNRobots_Popular_Posts_Core', 'delete_unapproved_comment'));

class NNRobots_Popular_Posts_Core {

	/**
	 * Hooks into the wp_enqueue_scripts and adds the js file to record views
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function loadAJAXScript() {

		wp_enqueue_script(NNRobots_Popular_Posts::$prefix . 'add_view_js', plugins_url('js/popular-posts.js', __FILE__), array('jquery'));
		wp_localize_script(NNRobots_Popular_Posts::$prefix . 'add_view_js', 'nnr_pp_add_view_data', array(
			'prefix'	=> NNRobots_Popular_Posts::$prefix_dash,
			'ajaxurl'	=> admin_url( 'admin-ajax.php' ),
		));

	}

	/**
	 * Adds a Post ID DOM element to the bottom of a post
	 *
	 * @access public
	 * @static
	 * @param mixed $content
	 * @return void
	 */
	static function addPostID($content) {

		// Add DOM element used to record a view

		if (is_singular()) {

			global $post;

			return $content . '<p class="' . NNRobots_Popular_Posts::$prefix_dash . 'popular-posts-id" style="display: none !important;">' . $post->ID  . '</p>';
		}

		return $content;
	}

	/**
	 * Runs via AJAX
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function addView() {

		include_once('model/db.php');

		// Check if post id is set

		if (!isset($_POST['post_id'])) {
			echo 'Popular Posts view was NOT recorded because no post id found';
			die();
		}

		// Only record view if on is_singular() page

		if (!is_admin() && !is_singular()) {
			echo 'Popular Posts view was NOT recorded because this page is not a post';
			die();
		}

		global $current_user;

		$settings = get_option(NNRobots_Popular_Posts::$prefix . 'settings');

		// Default values

		if ($settings === false) {
			$settings = NNRobots_Popular_Posts::$default;
		}

		// Admins

		if (isset($settings['exclude_views']) && $settings['exclude_views'] == 'admins') {
			if (!current_user_can('manage_options')) {
				NNRobots_Popular_Posts_DB::addView($_POST['post_id']);
				echo 'Popular Posts view was recorded';
				die();
			}
		}

		// Author

		else if (isset($settings['exclude_views']) && $settings['exclude_views'] == 'author') {
			if ($current_user->ID != $post->post_author) {
				NNRobots_Popular_Posts_DB::addView($_POST['post_id']);
				echo 'Popular Posts view was recorded';
				die();
			}
		}

		// Users

		else if (isset($settings['exclude_views']) && $settings['exclude_views'] == 'users') {
			if (!is_user_logged_in()) {
				NNRobots_Popular_Posts_DB::addView($_POST['post_id']);
				echo 'Popular Posts view was recorded';
				die();
			}
		}

		// Anyone

		else if (isset($settings['exclude_views']) && $settings['exclude_views'] == 'no_one') {
			NNRobots_Popular_Posts_DB::addView($_POST['post_id']);
			echo 'Popular Posts view was recorded';
			die();
		}

		echo 'Popular Posts view was NOT recorded';
		die();
	}

	/**
	 * Adds 1 to the shortcode counter everytime someone clicks the insert shortcode button
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function shortcodeIncrement() {

		$shortcode_counter = get_option(NNRobots_Popular_Posts::$prefix . 'shortcode_counter');

		if ($shortcode_counter === false) {
	   		$shortcode_counter = 1;
    	}

    	$shortcode_counter++;

    	update_option(NNRobots_Popular_Posts::$prefix . 'shortcode_counter', $shortcode_counter);

    	echo $shortcode_counter;
    	die();
	}

	/**
	 * Hook for adding a comment
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function add_comment($comment_ID, $spam) {

		error_log('hello');

		include_once('model/db.php');

		$post = get_post(get_comment($comment_ID)->comment_post_ID);

		if ($spam) {
			NNRobots_Popular_Posts_DB::addComment($post->ID, $comment_ID);
		}

	}

	/**
	 * Hook for adding an approved comment
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function add_approved_comment($comment) {

		include_once('model/db.php');

		$post = get_post(get_comment($comment->comment_ID)->comment_post_ID);

		NNRobots_Popular_Posts_DB::addComment($post->ID, $comment->comment_ID);

	}

	/**
	 * Hook for deleting a unapproved comment
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function delete_unapproved_comment($comment) {

		include_once('model/db.php');

		NNRobots_Popular_Posts_DB::deleteComment($comment->comment_ID);

	}

	/**
	 * Hook for deleting a comment
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function delete_comment($comment_ID) {

		include_once('model/db.php');

		NNRobots_Popular_Posts_DB::deleteComment($comment->comment_ID);

	}

}